# django imports
from django.shortcuts import render_to_response
from django.template import RequestContext

from postal.forms import PostalAddressForm

from de.forms import DEPostalAddressForm
from gb.forms import GBPostalAddressForm
from ie.forms import IEPostalAddressForm
from nl.forms import NLPostalAddressForm
from us.forms import USPostalAddressForm
import settings as postal_settings


country_map = {"de": DEPostalAddressForm,
               "gb": GBPostalAddressForm,
               "ie": IEPostalAddressForm,
               "nl": NLPostalAddressForm,
               "us": USPostalAddressForm,
              }

def get_postal_form_class(country_code):
    if postal_settings.POSTAL_ADDRESS_L10N:
        return country_map.get(country_code.lower(), PostalAddressForm)
    else:
        return PostalAddressForm



"""
Model of Postal Address, could possibly use some ideas from
http://www.djangosnippets.org/snippets/912/ in the future
"""
# django imports
from django.db import models
from django.utils.translation import ugettext_lazy as _

# other imports
from countries.models import Country

class PostalAddress(models.Model):
    # corresponds to a street address or house name
    line1 = models.CharField(_("line1"), max_length=100, default=u'', blank=True, null=True)

    # corresponds to a village, area or locality
    line2 = models.CharField(_("line2"), max_length=100, default=u'', blank=True, null=True)

    # corresponds to a town, or city
    city = models.CharField(_("Town/City"), max_length=100, default=u'', blank=True, null=True)

    # corresponds to state, province  or county
    state = models.CharField(_("State/Province/County"), max_length=100, default=u'', blank=True, null=True)

    # corresponds to zip code or postcode
    code = models.CharField(_("Zip Code/PostCode"), max_length=100, default=u'', blank=True, null=True)

    # country
    country = models.ForeignKey(Country, verbose_name=_("Country"), blank=True, null=True)

    def __unicode__(self):
        return "%s, %s, %s, %s, %s, %s" % (self.line1, self.line2, self.city, self.state, self.code, self.country)

    class Meta:
        verbose_name_plural = "Postal Addresses"



# django imports
#from django.contrib.gis import admin
from django.contrib import admin

# lfs imports
from postal.models import PostalAddress

admin.site.register(PostalAddress)
#admin.site.register(PostalAddress,admin.GeoModelAdmin)


DEBUG=True
DATABASE_ENGINE = 'sqlite3'
DATABASE_NAME = '/tmp/postal.db'
INSTALLED_APPS = ['django.contrib.admin',
                  'django.contrib.auth',
                  'django.contrib.contenttypes',
                  'django.contrib.sessions',
                  'countries',
                  'postal',]
ROOT_URLCONF = 'postal.tests.urls'



from django import forms
from django.utils.translation import ugettext_lazy as _

from models import PostalAddress
from settings import POSTAL_ADDRESS_LINE1, POSTAL_ADDRESS_LINE2, POSTAL_ADDRESS_CITY, POSTAL_ADDRESS_STATE, POSTAL_ADDRESS_CODE

class PostalAddressForm(forms.ModelForm):
    line1 = forms.CharField(label=POSTAL_ADDRESS_LINE1[0], required=POSTAL_ADDRESS_LINE1[1], max_length=100)
    line2 = forms.CharField(label=POSTAL_ADDRESS_LINE2[0], required=POSTAL_ADDRESS_LINE2[1], max_length=100)
    city = forms.CharField(label=POSTAL_ADDRESS_CITY[0], required=POSTAL_ADDRESS_CITY[1], max_length=100)
    state = forms.CharField(label=POSTAL_ADDRESS_STATE[0], required=POSTAL_ADDRESS_STATE[1], max_length=100)
    code = forms.CharField(label=POSTAL_ADDRESS_CODE[0], required=POSTAL_ADDRESS_CODE[1], max_length=100)

    class Meta:
        model = PostalAddress
        



from django.shortcuts import render_to_response
from django.template import RequestContext

from postal.library import country_map, get_postal_form_class

def test_postal(request, country_code="ie"):
    country_code = request.GET.get('country_code', country_code)
    countries = []
    for k,v in country_map.items():
        countries.append(k)
    form_class = get_postal_form_class(country_code)
    form = form_class()
        
    context = RequestContext(request, locals())    
    return render_to_response('postal/test.html', context)